@@ -134,13 +134,13 @@ protected:
 
     void cleanUp();
 
-    OperationMode m_operationMode = List;
+    OperationMode m_operationMode = NoOperation;
     CliProperties *m_cliProps = nullptr;
     QString m_oldWorkingDirExtraction; // Used ONLY by extraction jobs.
     QString m_oldWorkingDir; // Used by copy and move jobs.
     QScopedPointer<QTemporaryDir> m_tempWorkingDir;
     QScopedPointer<QTemporaryDir> m_tempAddDir;
-    OperationMode m_subOperation = List;
+    OperationMode m_subOperation = NoOperation;
     QVector<Archive::Entry*> m_passedFiles;
     QVector<Archive::Entry*> m_tempAddedFiles;
     Archive::Entry *m_passedDestination = nullptr;
@@ -154,7 +154,7 @@ protected:
 
     bool m_abortingOperation = false;
 
-protected slots:
+protected Q_SLOTS:
     virtual void readStdout(bool handleAll = false);
 
 private:
@@ -217,10 +217,10 @@ private:
     qulonglong m_archiveSizeOnDisk = 0;
     qulonglong m_listedSize = 0;
 
-protected slots:
+protected Q_SLOTS:
     virtual void processFinished(int exitCode, QProcess::ExitStatus exitStatus);
 
-private slots:
+private Q_SLOTS:
     void extractProcessFinished(int exitCode, QProcess::ExitStatus exitStatus);
     void continueCopying(bool result);
     void onEntry(Archive::Entry *archiveEntry);
